@@ -18,7 +18,7 @@ from pyiron_base.job.util import \
     _copy_database_entry, \
     _copy_to_delete_existing, \
     _rename_job, \
-    _is_valid_job_name, \
+    _get_safe_job_name, \
     _job_is_archived, \
     _job_archive, \
     _job_unarchive, \
@@ -104,7 +104,7 @@ class JobCore(HasGroups):
     """
 
     def __init__(self, project, job_name):
-        _is_valid_job_name(job_name)
+        job_name = _get_safe_job_name(job_name)
         self._name = job_name
         self._hdf5 = project.open(self._name)
         self._job_id = None
@@ -492,17 +492,26 @@ class JobCore(HasGroups):
             )
         return self.project_hdf5.to_object(object_type, **qwargs)
 
-    def get(self, name):
+    def get(self, name, default=None):
         """
         Internal wrapper function for __getitem__() - self[name]
 
         Args:
             key (str, slice): path to the data or key of the data object
+            default (any, optional): return this if key cannot be found
 
         Returns:
             dict, list, float, int: data or data object
+
+        Raises:
+            ValueError: key cannot be found and default is not given
         """
-        return self.__getitem__(name)
+        try:
+            return self.__getitem__(name)
+        except ValueError:
+            if default is not None:
+                return default
+            raise
 
     def load(self, job_specifier, convert_to_object=True):
         """
