@@ -6,7 +6,9 @@ Worker Class to execute calculation in an asynchronous way
 """
 import os
 import time
+from datetime import datetime
 from multiprocessing.pool import ThreadPool
+import numpy as np
 from pyiron_base.job.template import PythonTemplateJob
 
 
@@ -108,6 +110,7 @@ class WorkerJob(PythonTemplateJob):
         self.input.project = None
         self.input.cores_per_job = 1
         self.input.sleep_interval = 10
+        self.input.child_runtime = 0
 
     @property
     def project_to_watch(self):
@@ -129,6 +132,14 @@ class WorkerJob(PythonTemplateJob):
     def cores_per_job(self, cores):
         self.input.cores_per_job = int(cores)
 
+    @property
+    def child_runtime(self):
+        return self.input.child_runtime
+
+    @child_runtime.setter
+    def child_runtime(self, time_in_sec):
+        self.input.child_runtime = time_in_sec
+
     @property
     def sleep_interval(self):
         return self.input.sleep_interval
@@ -142,6 +153,8 @@ class WorkerJob(PythonTemplateJob):
         self.status.running = True
         master_id = self.job_id
         pr = self.project_to_watch
+        self.project_hdf5.create_working_directory()
+        log_file = os.path.join(self.working_directory, "worker.log")
         active_job_ids = []
         with ThreadPool(
             processes=int(self.server.cores / self.cores_per_job)
@@ -170,10 +183,27 @@ class WorkerJob(PythonTemplateJob):
                     ]
                     active_job_ids += [j[1] for j in job_lst]
                     pool.map_async(worker_function, job_lst)
-                elif self.status.collect:  # The infinite loop can be stopped by setting the job status to collect.
-                    break
+                elif self.status.collect or self.status.aborted or self.status.finished:
+                    break  # The infinite loop can be stopped by setting the job status to collect.
                 else:  # The sleep interval can be set as part of the input
+                    if self.input.child_runtime > 0:
+                        df_run = df[
+                            (df["status"] == "running") &
+                            (df["masterid"] == master_id)
+                        ]
+                        if len(df_run) > 0:
+                            for job_id in df_run[
+                                (
+                                    np.array(datetime.now(), dtype='datetime64[ns]') - df_run.timestart.values
+                                ).astype('timedelta64[s]') > np.array(self.input.child_runtime).astype('timedelta64[s]')
+                            ].id.values:
+                                self.project.db.set_job_status(job_id=job_id, status="aborted")
                     time.sleep(self.input.sleep_interval)
 
+                # job submission
+                with open(log_file, "a") as f:
+                    f.write(str(datetime.today()) + " " + str(len(active_job_ids)) + " " + str(len(df)) + " " + str(
+                        len(df_sub)) + "\n")
+
         # The job is finished
         self.status.finished = True
