@@ -31,6 +31,7 @@ from pyiron_base.database.jobtable import (
 from pyiron_base.generic.hdfio import ProjectHDFio
 from pyiron_base.generic.filedata import load_file
 from pyiron_base.generic.util import deprecate
+from pyiron_base.job.util import _special_symbol_replacements, _get_safe_job_name
 from pyiron_base.interfaces.has_groups import HasGroups
 from pyiron_base.job.jobtype import JobType, JobTypeChoice, JobFactory
 from pyiron_base.server.queuestatus import (
@@ -46,7 +47,7 @@ from pyiron_base.server.queuestatus import (
 from pyiron_base.job.external import Notebook
 from pyiron_base.project.data import ProjectData
 from pyiron_base.archiving import import_archive, export_archive
-from typing import Generator
+from typing import Generator, Union, Dict
 
 __author__ = "Joerg Neugebauer, Jan Janssen"
 __copyright__ = (
@@ -958,7 +959,7 @@ class Project(ProjectPath, HasGroups):
             else:
                 raise EnvironmentError("copy_to: is not available in Viewermode !")
 
-    def remove_jobs(self, recursive=False):
+    def remove_jobs(self, recursive=False, progress=True):
         """
         Remove all jobs in the current project and in all subprojects if recursive=True is selected - see also
         remove_job().
@@ -968,6 +969,7 @@ class Project(ProjectPath, HasGroups):
 
         Args:
             recursive (bool): [True/False] delete all jobs in all subprojects - default=False
+            progress (bool): if True (default), add an interactive progress bar to the iteration
         """
         if not isinstance(recursive, bool):
             raise ValueError('recursive must be a boolean')
@@ -983,22 +985,26 @@ class Project(ProjectPath, HasGroups):
                     "Invalid response. Please enter 'y' (yes) or 'n' (no): "
                     ).lower()
         if confirmed == "y":
-            self.remove_jobs_silently(recursive=recursive)
+            self.remove_jobs_silently(recursive=recursive, progress=progress)
         else:
             print(f"No jobs removed from '{self.base_name}'.")
 
-    def remove_jobs_silently(self, recursive=False):
+    def remove_jobs_silently(self, recursive=False, progress=True):
         """
         Remove all jobs in the current project and in all subprojects if recursive=True is selected - see also
         remove_job()
 
         Args:
             recursive (bool): [True/False] delete all jobs in all subprojects - default=False
+            progress (bool): if True (default), add an interactive progress bar to the iteration
         """
         if not isinstance(recursive, bool):
             raise ValueError('recursive must be a boolean')
         if not self.view_mode:
-            for job_id in self.get_job_ids(recursive=recursive):
+            job_id_lst = self.get_job_ids(recursive=recursive)
+            if progress and len(job_id_lst) > 0:
+                job_id_lst = tqdm(job_id_lst)
+            for job_id in job_id_lst:
                 if job_id not in self.get_job_ids(recursive=recursive):
                     continue
                 else:
@@ -1589,6 +1595,33 @@ class Creator:
     def job(self):
         return self._job_factory
 
+    @staticmethod
+    def job_name(
+        job_name: str, ndigits: Union[int, None] = 8, special_symbols: Union[Dict, None] = None
+    ):
+        """
+        Creation of job names with special symbol replacement and rounding of floating numbers
+
+        Args:
+            job_name (str/list): Job name
+            ndigits (int/None): Decimal digits to round floats to a given precision. `None` if
+                no rounding should be performed.
+            special_symbols (dict): Replacement of special symbols.
+
+        Returns:
+            (str): Job name
+
+        Default `special_symbols`: default_special_symbols_to_be_replaced
+        """
+        return _get_safe_job_name(
+            name=job_name, ndigits=ndigits, special_symbols=special_symbols
+        )
+
+    job_name.__doc__ = job_name.__doc__.replace(
+        'default_special_symbols_to_be_replaced',
+        str(_special_symbol_replacements)
+    )
+
     def table(self, job_name="table", delete_existing_job=False):
         """
         Create pyiron table
